@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008_001;
 
-use version; our $VERSION = 'v0.9.1';
+use version; our $VERSION = 'v0.9.2';
 
 our @COMMANDS_INFO = (
     +{
@@ -74,6 +74,19 @@ Usage:
 
 Description:
     See "\h detaildump"
+EODESC
+    },
+    +{
+        command => 'randomset',
+        summary => 'Generate sample data and SET them',
+        description => <<'EODESC',
+Usage:
+    > randomset [<NUMBER> [<MAX_LENGTH> [<MIN_LENGTH> [<NAMESPACE>]]]]
+    > randomset                     # generate 100 data
+    > randomset 50                  # generate 50 data
+    > randomset 50 1024             # data length:   1-1024B
+    > randomset 50 1024 256         # data length: 256-1024B
+    > randomset 50 1024 256 sample1 # prefix 'sample1:'
 EODESC
     },
     +{
